/*! For license information please see 670f2ab5.js.LICENSE.txt */
"use strict";(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[3103],{18601:(e,t,n)=>{n.d(t,{qN:()=>a.q,Wg:()=>d});var i,o,s=n(87480),r=n(5701),a=n(78220);const l=null!==(o=null===(i=window.ShadyDOM)||void 0===i?void 0:i.inUse)&&void 0!==o&&o;class d extends a.H{constructor(){super(...arguments),this.disabled=!1,this.containingForm=null,this.formDataListener=e=>{this.disabled||this.setFormData(e.formData)}}findFormElement(){if(!this.shadowRoot||l)return null;const e=this.getRootNode().querySelectorAll("form");for(const t of Array.from(e))if(t.contains(this))return t;return null}connectedCallback(){var e;super.connectedCallback(),this.containingForm=this.findFormElement(),null===(e=this.containingForm)||void 0===e||e.addEventListener("formdata",this.formDataListener)}disconnectedCallback(){var e;super.disconnectedCallback(),null===(e=this.containingForm)||void 0===e||e.removeEventListener("formdata",this.formDataListener),this.containingForm=null}click(){this.formElement&&!this.disabled&&(this.formElement.focus(),this.formElement.click())}firstUpdated(){super.firstUpdated(),this.shadowRoot&&this.mdcRoot.addEventListener("change",(e=>{this.dispatchEvent(new Event("change",e))}))}}d.shadowRootOptions={mode:"open",delegatesFocus:!0},(0,s.__decorate)([(0,r.C)({type:Boolean})],d.prototype,"disabled",void 0)},15112:(e,t,n)=>{n.d(t,{P:()=>o});n(94604);var i=n(9672);class o{constructor(e){o[" "](e),this.type=e&&e.type||"default",this.key=e&&e.key,e&&"value"in e&&(this.value=e.value)}get value(){var e=this.type,t=this.key;if(e&&t)return o.types[e]&&o.types[e][t]}set value(e){var t=this.type,n=this.key;t&&n&&(t=o.types[t]=o.types[t]||{},null==e?delete t[n]:t[n]=e)}get list(){if(this.type){var e=o.types[this.type];return e?Object.keys(e).map((function(e){return s[this.type][e]}),this):[]}}byKey(e){return this.key=e,this.value}}o[" "]=function(){},o.types={};var s=o.types;(0,i.k)({is:"iron-meta",properties:{type:{type:String,value:"default"},key:{type:String},value:{type:String,notify:!0},self:{type:Boolean,observer:"_selfChanged"},__meta:{type:Boolean,computed:"__computeMeta(type, key, value)"}},hostAttributes:{hidden:!0},__computeMeta:function(e,t,n){var i=new o({type:e,key:t});return void 0!==n&&n!==i.value?i.value=n:this.value!==i.value&&(this.value=i.value),i},get list(){return this.__meta&&this.__meta.list},_selfChanged:function(e){e&&(this.value=this)},byKey:function(e){return new o({type:this.type,key:e}).value}})},81563:(e,t,n)=>{n.d(t,{E_:()=>f,i9:()=>v,_Y:()=>d,pt:()=>s,OR:()=>a,hN:()=>r,ws:()=>p,fk:()=>u,hl:()=>h});var i=n(15304);const{H:o}=i.Al,s=e=>null===e||"object"!=typeof e&&"function"!=typeof e,r=(e,t)=>{var n,i;return void 0===t?void 0!==(null===(n=e)||void 0===n?void 0:n._$litType$):(null===(i=e)||void 0===i?void 0:i._$litType$)===t},a=e=>void 0===e.strings,l=()=>document.createComment(""),d=(e,t,n)=>{var i;const s=e._$AA.parentNode,r=void 0===t?e._$AB:t._$AA;if(void 0===n){const t=s.insertBefore(l(),r),i=s.insertBefore(l(),r);n=new o(t,i,e,e.options)}else{const t=n._$AB.nextSibling,o=n._$AM,a=o!==e;if(a){let t;null===(i=n._$AQ)||void 0===i||i.call(n,e),n._$AM=e,void 0!==n._$AP&&(t=e._$AU)!==o._$AU&&n._$AP(t)}if(t!==r||a){let e=n._$AA;for(;e!==t;){const t=e.nextSibling;s.insertBefore(e,r),e=t}}}return n},u=(e,t,n=e)=>(e._$AI(t,n),e),c={},h=(e,t=c)=>e._$AH=t,v=e=>e._$AH,p=e=>{var t;null===(t=e._$AP)||void 0===t||t.call(e,!1,!0);let n=e._$AA;const i=e._$AB.nextSibling;for(;n!==i;){const e=n.nextSibling;n.remove(),n=e}},f=e=>{e._$AR()}},57835:(e,t,n)=>{n.d(t,{Xe:()=>i.Xe,pX:()=>i.pX,XM:()=>i.XM});var i=n(38941)}}]);