/*! For license information please see 97fabc3f.js.LICENSE.txt */
"use strict";(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[7909],{63207:(e,t,n)=>{n(65660),n(15112);var r=n(9672),i=n(87156),s=n(50856),a=n(94604);(0,r.k)({_template:s.d`
    <style>
      :host {
        @apply --layout-inline;
        @apply --layout-center-center;
        position: relative;

        vertical-align: middle;

        fill: var(--iron-icon-fill-color, currentcolor);
        stroke: var(--iron-icon-stroke-color, none);

        width: var(--iron-icon-width, 24px);
        height: var(--iron-icon-height, 24px);
        @apply --iron-icon;
      }

      :host([hidden]) {
        display: none;
      }
    </style>
`,is:"iron-icon",properties:{icon:{type:String},theme:{type:String},src:{type:String},_meta:{value:a.XY.create("iron-meta",{type:"iconset"})}},observers:["_updateIcon(_meta, isAttached)","_updateIcon(theme, isAttached)","_srcChanged(src, isAttached)","_iconChanged(icon, isAttached)"],_DEFAULT_ICONSET:"icons",_iconChanged:function(e){var t=(e||"").split(":");this._iconName=t.pop(),this._iconsetName=t.pop()||this._DEFAULT_ICONSET,this._updateIcon()},_srcChanged:function(e){this._updateIcon()},_usesIconset:function(){return this.icon||!this.src},_updateIcon:function(){this._usesIconset()?(this._img&&this._img.parentNode&&(0,i.vz)(this.root).removeChild(this._img),""===this._iconName?this._iconset&&this._iconset.removeIcon(this):this._iconsetName&&this._meta&&(this._iconset=this._meta.byKey(this._iconsetName),this._iconset?(this._iconset.applyIcon(this,this._iconName,this.theme),this.unlisten(window,"iron-iconset-added","_updateIcon")):this.listen(window,"iron-iconset-added","_updateIcon"))):(this._iconset&&this._iconset.removeIcon(this),this._img||(this._img=document.createElement("img"),this._img.style.width="100%",this._img.style.height="100%",this._img.draggable=!1),this._img.src=this.src,(0,i.vz)(this.root).appendChild(this._img))}})},15112:(e,t,n)=>{n.d(t,{P:()=>i});n(94604);var r=n(9672);class i{constructor(e){i[" "](e),this.type=e&&e.type||"default",this.key=e&&e.key,e&&"value"in e&&(this.value=e.value)}get value(){var e=this.type,t=this.key;if(e&&t)return i.types[e]&&i.types[e][t]}set value(e){var t=this.type,n=this.key;t&&n&&(t=i.types[t]=i.types[t]||{},null==e?delete t[n]:t[n]=e)}get list(){if(this.type){var e=i.types[this.type];return e?Object.keys(e).map((function(e){return s[this.type][e]}),this):[]}}byKey(e){return this.key=e,this.value}}i[" "]=function(){},i.types={};var s=i.types;(0,r.k)({is:"iron-meta",properties:{type:{type:String,value:"default"},key:{type:String},value:{type:String,notify:!0},self:{type:Boolean,observer:"_selfChanged"},__meta:{type:Boolean,computed:"__computeMeta(type, key, value)"}},hostAttributes:{hidden:!0},__computeMeta:function(e,t,n){var r=new i({type:e,key:t});return void 0!==n&&n!==r.value?r.value=n:this.value!==r.value&&(this.value=r.value),r},get list(){return this.__meta&&this.__meta.list},_selfChanged:function(e){e&&(this.value=this)},byKey:function(e){return new i({type:this.type,key:e}).value}})},23682:(e,t,n)=>{function r(e,t){if(t.length<e)throw new TypeError(e+" argument"+(e>1?"s":"")+" required, but only "+t.length+" present")}n.d(t,{Z:()=>r})},90394:(e,t,n)=>{function r(e){if(null===e||!0===e||!1===e)return NaN;var t=Number(e);return isNaN(t)?t:t<0?Math.ceil(t):Math.floor(t)}n.d(t,{Z:()=>r})},79021:(e,t,n)=>{n.d(t,{Z:()=>a});var r=n(90394),i=n(34327),s=n(23682);function a(e,t){(0,s.Z)(2,arguments);var n=(0,i.Z)(e),a=(0,r.Z)(t);return isNaN(a)?new Date(NaN):a?(n.setDate(n.getDate()+a),n):n}},59699:(e,t,n)=>{n.d(t,{Z:()=>o});var r=n(90394),i=n(39244),s=n(23682),a=36e5;function o(e,t){(0,s.Z)(2,arguments);var n=(0,r.Z)(t);return(0,i.Z)(e,n*a)}},39244:(e,t,n)=>{n.d(t,{Z:()=>a});var r=n(90394),i=n(34327),s=n(23682);function a(e,t){(0,s.Z)(2,arguments);var n=(0,i.Z)(e).getTime(),a=(0,r.Z)(t);return new Date(n+a)}},32182:(e,t,n)=>{n.d(t,{Z:()=>a});var r=n(90394),i=n(34327),s=n(23682);function a(e,t){(0,s.Z)(2,arguments);var n=(0,i.Z)(e),a=(0,r.Z)(t);if(isNaN(a))return new Date(NaN);if(!a)return n;var o=n.getDate(),u=new Date(n.getTime());u.setMonth(n.getMonth()+a+1,0);var c=u.getDate();return o>=c?u:(n.setFullYear(u.getFullYear(),u.getMonth(),o),n)}},93752:(e,t,n)=>{n.d(t,{Z:()=>s});var r=n(34327),i=n(23682);function s(e){(0,i.Z)(1,arguments);var t=(0,r.Z)(e);return t.setHours(23,59,59,999),t}},70390:(e,t,n)=>{n.d(t,{Z:()=>i});var r=n(93752);function i(){return(0,r.Z)(Date.now())}},47538:(e,t,n)=>{function r(){var e=new Date,t=e.getFullYear(),n=e.getMonth(),r=e.getDate(),i=new Date(0);return i.setFullYear(t,n,r-1),i.setHours(23,59,59,999),i}n.d(t,{Z:()=>r})},59429:(e,t,n)=>{n.d(t,{Z:()=>s});var r=n(34327),i=n(23682);function s(e){(0,i.Z)(1,arguments);var t=(0,r.Z)(e);return t.setHours(0,0,0,0),t}},13250:(e,t,n)=>{n.d(t,{Z:()=>s});var r=n(34327),i=n(23682);function s(e){(0,i.Z)(1,arguments);var t=(0,r.Z)(e);return t.setDate(1),t.setHours(0,0,0,0),t}},27088:(e,t,n)=>{n.d(t,{Z:()=>i});var r=n(59429);function i(){return(0,r.Z)(Date.now())}},83008:(e,t,n)=>{function r(){var e=new Date,t=e.getFullYear(),n=e.getMonth(),r=e.getDate(),i=new Date(0);return i.setFullYear(t,n,r-1),i.setHours(0,0,0,0),i}n.d(t,{Z:()=>r})},34327:(e,t,n)=>{n.d(t,{Z:()=>i});var r=n(23682);function i(e){(0,r.Z)(1,arguments);var t=Object.prototype.toString.call(e);return e instanceof Date||"object"==typeof e&&"[object Date]"===t?new Date(e.getTime()):"number"==typeof e||"[object Number]"===t?new Date(e):("string"!=typeof e&&"[object String]"!==t||"undefined"==typeof console||(console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://git.io/fjule"),console.warn((new Error).stack)),new Date(NaN))}},21560:(e,t,n)=>{n.d(t,{ZH:()=>h,MT:()=>s,U2:()=>u,RV:()=>i,t8:()=>c});const r=function(){if(!(!navigator.userAgentData&&/Safari\//.test(navigator.userAgent)&&!/Chrom(e|ium)\//.test(navigator.userAgent))||!indexedDB.databases)return Promise.resolve();let e;return new Promise((t=>{const n=()=>indexedDB.databases().finally(t);e=setInterval(n,100),n()})).finally((()=>clearInterval(e)))};function i(e){return new Promise(((t,n)=>{e.oncomplete=e.onsuccess=()=>t(e.result),e.onabort=e.onerror=()=>n(e.error)}))}function s(e,t){const n=r().then((()=>{const n=indexedDB.open(e);return n.onupgradeneeded=()=>n.result.createObjectStore(t),i(n)}));return(e,r)=>n.then((n=>r(n.transaction(t,e).objectStore(t))))}let a;function o(){return a||(a=s("keyval-store","keyval")),a}function u(e,t=o()){return t("readonly",(t=>i(t.get(e))))}function c(e,t,n=o()){return n("readwrite",(n=>(n.put(t,e),i(n.transaction))))}function h(e=o()){return e("readwrite",(e=>(e.clear(),i(e.transaction))))}}}]);
//# sourceMappingURL=97fabc3f.js.map