"use strict";(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[3927],{59699:(e,t,r)=>{r.d(t,{Z:()=>o});var n=r(90394),a=r(39244),u=r(23682),s=36e5;function o(e,t){(0,u.Z)(2,arguments);var r=(0,n.Z)(t);return(0,a.Z)(e,r*s)}},39244:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(90394),a=r(34327),u=r(23682);function s(e,t){(0,u.Z)(2,arguments);var r=(0,a.Z)(e).getTime(),s=(0,n.Z)(t);return new Date(r+s)}},33651:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(90394),a=r(79021),u=r(23682);function s(e,t){(0,u.Z)(2,arguments);var r=(0,n.Z)(t),s=7*r;return(0,a.Z)(e,s)}},27605:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(90394),a=r(32182),u=r(23682);function s(e,t){(0,u.Z)(2,arguments);var r=(0,n.Z)(t);return(0,a.Z)(e,12*r)}},4535:(e,t,r)=>{r.d(t,{Z:()=>i});var n=r(34327);function a(e){var t=new Date(Date.UTC(e.getFullYear(),e.getMonth(),e.getDate(),e.getHours(),e.getMinutes(),e.getSeconds(),e.getMilliseconds()));return t.setUTCFullYear(e.getFullYear()),e.getTime()-t.getTime()}var u=r(59429),s=r(23682),o=864e5;function l(e,t){(0,s.Z)(2,arguments);var r=(0,u.Z)(e),n=(0,u.Z)(t),l=r.getTime()-a(r),Z=n.getTime()-a(n);return Math.round((l-Z)/o)}function Z(e,t){var r=e.getFullYear()-t.getFullYear()||e.getMonth()-t.getMonth()||e.getDate()-t.getDate()||e.getHours()-t.getHours()||e.getMinutes()-t.getMinutes()||e.getSeconds()-t.getSeconds()||e.getMilliseconds()-t.getMilliseconds();return r<0?-1:r>0?1:r}function i(e,t){(0,s.Z)(2,arguments);var r=(0,n.Z)(e),a=(0,n.Z)(t),u=Z(r,a),o=Math.abs(l(r,a));r.setDate(r.getDate()-u*o);var i=Number(Z(r,a)===-u),g=u*(o-i);return 0===g?0:g}},93752:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e);return t.setHours(23,59,59,999),t}},1905:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e),r=t.getMonth();return t.setFullYear(t.getFullYear(),r+1,0),t.setHours(23,59,59,999),t}},59281:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(34327),a=r(90394),u=r(23682);function s(e,t){(0,u.Z)(1,arguments);var r=t||{},s=r.locale,o=s&&s.options&&s.options.weekStartsOn,l=null==o?0:(0,a.Z)(o),Z=null==r.weekStartsOn?l:(0,a.Z)(r.weekStartsOn);if(!(Z>=0&&Z<=6))throw new RangeError("weekStartsOn must be between 0 and 6 inclusively");var i=(0,n.Z)(e),g=i.getDay(),v=6+(g<Z?-7:0)-(g-Z);return i.setDate(i.getDate()+v),i.setHours(23,59,59,999),i}},70451:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e),r=t.getFullYear();return t.setFullYear(r+1,0,0),t.setHours(23,59,59,999),t}},59401:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(34327),a=r(90394),u=r(23682);function s(e,t){(0,u.Z)(1,arguments);var r=t||{},s=r.locale,o=s&&s.options&&s.options.weekStartsOn,l=null==o?0:(0,a.Z)(o),Z=null==r.weekStartsOn?l:(0,a.Z)(r.weekStartsOn);if(!(Z>=0&&Z<=6))throw new RangeError("weekStartsOn must be between 0 and 6 inclusively");var i=(0,n.Z)(e),g=i.getDay(),v=(g<Z?7:0)+g-Z;return i.setDate(i.getDate()-v),i.setHours(0,0,0,0),i}},69388:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e),r=new Date(0);return r.setFullYear(t.getFullYear(),0,1),r.setHours(0,0,0,0),r}}}]);