"use strict";(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[3927],{59699:function(t,e,n){n.d(e,{Z:function(){return i}});var r=n(90394),u=n(39244),a=n(23682),o=36e5;function i(t,e){(0,a.Z)(2,arguments);var n=(0,r.Z)(e);return(0,u.Z)(t,n*o)}},39244:function(t,e,n){n.d(e,{Z:function(){return o}});var r=n(90394),u=n(34327),a=n(23682);function o(t,e){(0,a.Z)(2,arguments);var n=(0,u.Z)(t).getTime(),o=(0,r.Z)(e);return new Date(n+o)}},33651:function(t,e,n){n.d(e,{Z:function(){return o}});var r=n(90394),u=n(79021),a=n(23682);function o(t,e){(0,a.Z)(2,arguments);var n=(0,r.Z)(e),o=7*n;return(0,u.Z)(t,o)}},27605:function(t,e,n){n.d(e,{Z:function(){return o}});var r=n(90394),u=n(32182),a=n(23682);function o(t,e){(0,a.Z)(2,arguments);var n=(0,r.Z)(e);return(0,u.Z)(t,12*n)}},4535:function(t,e,n){n.d(e,{Z:function(){return l}});var r=n(34327);function u(t){var e=new Date(Date.UTC(t.getFullYear(),t.getMonth(),t.getDate(),t.getHours(),t.getMinutes(),t.getSeconds(),t.getMilliseconds()));return e.setUTCFullYear(t.getFullYear()),t.getTime()-e.getTime()}var a=n(59429),o=n(23682),i=864e5;function s(t,e){(0,o.Z)(2,arguments);var n=(0,a.Z)(t),r=(0,a.Z)(e),s=n.getTime()-u(n),c=r.getTime()-u(r);return Math.round((s-c)/i)}function c(t,e){var n=t.getFullYear()-e.getFullYear()||t.getMonth()-e.getMonth()||t.getDate()-e.getDate()||t.getHours()-e.getHours()||t.getMinutes()-e.getMinutes()||t.getSeconds()-e.getSeconds()||t.getMilliseconds()-e.getMilliseconds();return n<0?-1:n>0?1:n}function l(t,e){(0,o.Z)(2,arguments);var n=(0,r.Z)(t),u=(0,r.Z)(e),a=c(n,u),i=Math.abs(s(n,u));n.setDate(n.getDate()-a*i);var l=Number(c(n,u)===-a),Z=a*(i-l);return 0===Z?0:Z}},93752:function(t,e,n){n.d(e,{Z:function(){return a}});var r=n(34327),u=n(23682);function a(t){(0,u.Z)(1,arguments);var e=(0,r.Z)(t);return e.setHours(23,59,59,999),e}},1905:function(t,e,n){n.d(e,{Z:function(){return a}});var r=n(34327),u=n(23682);function a(t){(0,u.Z)(1,arguments);var e=(0,r.Z)(t),n=e.getMonth();return e.setFullYear(e.getFullYear(),n+1,0),e.setHours(23,59,59,999),e}},59281:function(t,e,n){n.d(e,{Z:function(){return o}});var r=n(34327),u=n(90394),a=n(23682);function o(t,e){(0,a.Z)(1,arguments);var n=e||{},o=n.locale,i=o&&o.options&&o.options.weekStartsOn,s=null==i?0:(0,u.Z)(i),c=null==n.weekStartsOn?s:(0,u.Z)(n.weekStartsOn);if(!(c>=0&&c<=6))throw new RangeError("weekStartsOn must be between 0 and 6 inclusively");var l=(0,r.Z)(t),Z=l.getDay(),f=6+(Z<c?-7:0)-(Z-c);return l.setDate(l.getDate()+f),l.setHours(23,59,59,999),l}},70451:function(t,e,n){n.d(e,{Z:function(){return a}});var r=n(34327),u=n(23682);function a(t){(0,u.Z)(1,arguments);var e=(0,r.Z)(t),n=e.getFullYear();return e.setFullYear(n+1,0,0),e.setHours(23,59,59,999),e}},59401:function(t,e,n){n.d(e,{Z:function(){return o}});var r=n(34327),u=n(90394),a=n(23682);function o(t,e){(0,a.Z)(1,arguments);var n=e||{},o=n.locale,i=o&&o.options&&o.options.weekStartsOn,s=null==i?0:(0,u.Z)(i),c=null==n.weekStartsOn?s:(0,u.Z)(n.weekStartsOn);if(!(c>=0&&c<=6))throw new RangeError("weekStartsOn must be between 0 and 6 inclusively");var l=(0,r.Z)(t),Z=l.getDay(),f=(Z<c?7:0)+Z-c;return l.setDate(l.getDate()-f),l.setHours(0,0,0,0),l}},69388:function(t,e,n){n.d(e,{Z:function(){return a}});var r=n(34327),u=n(23682);function a(t){(0,u.Z)(1,arguments);var e=(0,r.Z)(t),n=new Date(0);return n.setFullYear(e.getFullYear(),0,1),n.setHours(0,0,0,0),n}}}]);