"use strict";(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[4453],{23682:function(t,e,n){function r(t,e){if(e.length<t)throw new TypeError(t+" argument"+(t>1?"s":"")+" required, but only "+e.length+" present")}n.d(e,{Z:function(){return r}})},90394:function(t,e,n){function r(t){if(null===t||!0===t||!1===t)return NaN;var e=Number(t);return isNaN(e)?e:e<0?Math.ceil(e):Math.floor(e)}n.d(e,{Z:function(){return r}})},79021:function(t,e,n){n.d(e,{Z:function(){return a}});var r=n(90394),u=n(34327),o=n(23682);function a(t,e){(0,o.Z)(2,arguments);var n=(0,u.Z)(t),a=(0,r.Z)(e);return isNaN(a)?new Date(NaN):a?(n.setDate(n.getDate()+a),n):n}},59699:function(t,e,n){n.d(e,{Z:function(){return i}});var r=n(90394),u=n(39244),o=n(23682),a=36e5;function i(t,e){(0,o.Z)(2,arguments);var n=(0,r.Z)(e);return(0,u.Z)(t,n*a)}},39244:function(t,e,n){n.d(e,{Z:function(){return a}});var r=n(90394),u=n(34327),o=n(23682);function a(t,e){(0,o.Z)(2,arguments);var n=(0,u.Z)(t).getTime(),a=(0,r.Z)(e);return new Date(n+a)}},32182:function(t,e,n){n.d(e,{Z:function(){return a}});var r=n(90394),u=n(34327),o=n(23682);function a(t,e){(0,o.Z)(2,arguments);var n=(0,u.Z)(t),a=(0,r.Z)(e);if(isNaN(a))return new Date(NaN);if(!a)return n;var i=n.getDate(),c=new Date(n.getTime());c.setMonth(n.getMonth()+a+1,0);var f=c.getDate();return i>=f?c:(n.setFullYear(c.getFullYear(),c.getMonth(),i),n)}},4535:function(t,e,n){n.d(e,{Z:function(){return s}});var r=n(34327);function u(t){var e=new Date(Date.UTC(t.getFullYear(),t.getMonth(),t.getDate(),t.getHours(),t.getMinutes(),t.getSeconds(),t.getMilliseconds()));return e.setUTCFullYear(t.getFullYear()),t.getTime()-e.getTime()}var o=n(59429),a=n(23682),i=864e5;function c(t,e){(0,a.Z)(2,arguments);var n=(0,o.Z)(t),r=(0,o.Z)(e),c=n.getTime()-u(n),f=r.getTime()-u(r);return Math.round((c-f)/i)}function f(t,e){var n=t.getFullYear()-e.getFullYear()||t.getMonth()-e.getMonth()||t.getDate()-e.getDate()||t.getHours()-e.getHours()||t.getMinutes()-e.getMinutes()||t.getSeconds()-e.getSeconds()||t.getMilliseconds()-e.getMilliseconds();return n<0?-1:n>0?1:n}function s(t,e){(0,a.Z)(2,arguments);var n=(0,r.Z)(t),u=(0,r.Z)(e),o=f(n,u),i=Math.abs(c(n,u));n.setDate(n.getDate()-o*i);var s=Number(f(n,u)===-o),g=o*(i-s);return 0===g?0:g}},93752:function(t,e,n){n.d(e,{Z:function(){return o}});var r=n(34327),u=n(23682);function o(t){(0,u.Z)(1,arguments);var e=(0,r.Z)(t);return e.setHours(23,59,59,999),e}},70390:function(t,e,n){n.d(e,{Z:function(){return u}});var r=n(93752);function u(){return(0,r.Z)(Date.now())}},47538:function(t,e,n){function r(){var t=new Date,e=t.getFullYear(),n=t.getMonth(),r=t.getDate(),u=new Date(0);return u.setFullYear(e,n,r-1),u.setHours(23,59,59,999),u}n.d(e,{Z:function(){return r}})},3700:function(t,e,n){n.d(e,{Z:function(){return a}});var r=n(59429),u=n(23682);function o(t,e){(0,u.Z)(2,arguments);var n=(0,r.Z)(t),o=(0,r.Z)(e);return n.getTime()===o.getTime()}function a(t){return(0,u.Z)(1,arguments),o(t,Date.now())}},59429:function(t,e,n){n.d(e,{Z:function(){return o}});var r=n(34327),u=n(23682);function o(t){(0,u.Z)(1,arguments);var e=(0,r.Z)(t);return e.setHours(0,0,0,0),e}},13250:function(t,e,n){n.d(e,{Z:function(){return o}});var r=n(34327),u=n(23682);function o(t){(0,u.Z)(1,arguments);var e=(0,r.Z)(t);return e.setDate(1),e.setHours(0,0,0,0),e}},27088:function(t,e,n){n.d(e,{Z:function(){return u}});var r=n(59429);function u(){return(0,r.Z)(Date.now())}},83008:function(t,e,n){function r(){var t=new Date,e=t.getFullYear(),n=t.getMonth(),r=t.getDate(),u=new Date(0);return u.setFullYear(e,n,r-1),u.setHours(0,0,0,0),u}n.d(e,{Z:function(){return r}})},34327:function(t,e,n){n.d(e,{Z:function(){return o}});var r=n(23682);function u(t){return u="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},u(t)}function o(t){(0,r.Z)(1,arguments);var e=Object.prototype.toString.call(t);return t instanceof Date||"object"===u(t)&&"[object Date]"===e?new Date(t.getTime()):"number"==typeof t||"[object Number]"===e?new Date(t):("string"!=typeof t&&"[object String]"!==e||"undefined"==typeof console||(console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://git.io/fjule"),console.warn((new Error).stack)),new Date(NaN))}}}]);